@@ -32,16 +32,16 @@ import re
 import setuptools  # type: ignore
 
 
-RE_VERSION = r'''^
-    \s* VERSION_STRING \s* = \s* '
+RE_VERSION = r"""^
+    \s* VERSION_STRING \s* = \s* "
     (?P<version>
            (?: 0 | [1-9][0-9]* )    # major
         \. (?: 0 | [1-9][0-9]* )    # minor
         \. (?: 0 | [1-9][0-9]* )    # patchlevel
     (?: \. [a-zA-Z0-9]+ )?          # optional addendum (dev1, beta3, etc.)
     )
-    ' \s*
-    $'''
+    " \s*
+    $"""
 
 
 def get_version():
@@ -49,13 +49,13 @@ def get_version():
     """ Get the version string from the module's __init__ file. """
     found = None
     re_semver = re.compile(RE_VERSION, re.X)
-    with open('confget/defs.py') as init:
+    with open("confget/defs.py") as init:
         for line in init.readlines():
             match = re_semver.match(line)
             if not match:
                 continue
             assert found is None
-            found = match.group('version')
+            found = match.group("version")
 
     assert found is not None
     return found
@@ -64,69 +64,50 @@ def get_version():
 def get_long_description():
     # type: () -> str
     """ Get the package long description from the README file. """
-    with open('README.md') as readme:
+    with open("README.md") as readme:
         return readme.read()
 
 
 setuptools.setup(
-    name='confget',
+    name="confget",
     version=get_version(),
-
-    description='Parse configuration files and extract values from them',
+    description="Parse configuration files and extract values from them",
     long_description=get_long_description(),
-    long_description_content_type='text/markdown',
-
-    author='Peter Pentchev',
-    author_email='roam@ringlet.net',
-    url='https://devel.ringlet.net/textproc/confget/',
-
-    packages=['confget', 'confget.backend'],
+    long_description_content_type="text/markdown",
+    author="Peter Pentchev",
+    author_email="roam@ringlet.net",
+    url="https://devel.ringlet.net/textproc/confget/",
+    packages=["confget", "confget.backend"],
     package_data={
-        'confget': [
+        "confget": [
             # The typed module marker
-            'py.typed',
-        ],
+            "py.typed"
+        ]
     },
-
-    install_requires=[
-        'six',
-    ],
-
-    license='BSD-2',
+    install_requires=['configparser;python_version<"3"', "six"],
+    license="BSD-2",
     classifiers=[
-        'Development Status :: 5 - Production/Stable',
-
-        'Environment :: Console',
-
-        'Intended Audience :: Developers',
-        'Intended Audience :: System Administrators',
-
-        'License :: DFSG approved',
-        'License :: Freely Distributable',
-        'License :: OSI Approved :: BSD License',
-
-        'Operating System :: POSIX',
-        'Operating System :: Unix',
-
-        'Programming Language :: Python',
-        'Programming Language :: Python :: 2',
-        'Programming Language :: Python :: 2.6',
-        'Programming Language :: Python :: 2.7',
-        'Programming Language :: Python :: 3',
-        'Programming Language :: Python :: 3.5',
-        'Programming Language :: Python :: 3.6',
-        'Programming Language :: Python :: 3.7',
-
-        'Topic :: Software Development :: Libraries',
-        'Topic :: Software Development :: Libraries :: Python Modules',
-        'Topic :: Utilities',
+        "Development Status :: 5 - Production/Stable",
+        "Environment :: Console",
+        "Intended Audience :: Developers",
+        "Intended Audience :: System Administrators",
+        "License :: DFSG approved",
+        "License :: Freely Distributable",
+        "License :: OSI Approved :: BSD License",
+        "Operating System :: POSIX",
+        "Operating System :: Unix",
+        "Programming Language :: Python",
+        "Programming Language :: Python :: 2",
+        "Programming Language :: Python :: 2.6",
+        "Programming Language :: Python :: 2.7",
+        "Programming Language :: Python :: 3",
+        "Programming Language :: Python :: 3.5",
+        "Programming Language :: Python :: 3.6",
+        "Programming Language :: Python :: 3.7",
+        "Topic :: Software Development :: Libraries",
+        "Topic :: Software Development :: Libraries :: Python Modules",
+        "Topic :: Utilities",
     ],
-
-    entry_points={
-        'console_scripts': [
-            'confget=confget.__main__:main',
-        ],
-    },
-
+    entry_points={"console_scripts": ["confget=confget.__main__:main"]},
     zip_safe=True,
 )
