@@ -29,8 +29,6 @@ Load the test data, then run the tests using the objects provided by
 the Python library, not by executing the command-line tool.
 """
 
-from __future__ import print_function
-
 import itertools
 import os
 import sys
@@ -41,9 +39,13 @@ import pytest  # type: ignore
 
 from confget import format as cformat
 
-pytest.register_assert_rewrite('unit_tests.data.defs')
+pytest.register_assert_rewrite("unit_tests.data.defs")
 
-from . import data as tdata  # noqa: E402 pylint: disable=wrong-import-position
+# pylint: disable=wrong-import-position
+from .data import defs as tdefs  # noqa: E402
+from .data import load as tload  # noqa: E402
+
+# pylint: enable=wrong-import-position
 
 
 try:
@@ -54,22 +56,24 @@ except ImportError:
     pass
 
 
-TESTS = tdata.load_all_tests(os.environ['TESTDIR'])
+TESTS = tload.load_all_tests(os.environ["TESTDIR"])
 
-FULL_TEST_DATA = sorted(itertools.chain(*[
-    [
-        (
-            tfile[0],
-            idx,
-            tfile[1].setenv,
-            test,
+FULL_TEST_DATA = [
+    (fname, setenv, test)
+    for fname, idx, setenv, test in sorted(
+        itertools.chain(
+            *[
+                [
+                    (tfile[0], idx, tfile[1].setenv, test)
+                    for idx, test in enumerate(tfile[1].tests)
+                ]
+                for tfile in TESTS.items()
+            ]
         )
-        for idx, test in enumerate(tfile[1].tests)
-    ]
-    for tfile in TESTS.items()
-]))
+    )
+]
 
-SKIP_ARGS = set(['check_only'])
+SKIP_ARGS = set(["check_only"])
 
 
 @ddt.ddt
@@ -77,58 +81,42 @@ class TestStuff(unittest.TestCase):
     # pylint: disable=no-self-use
     """ Run the tests using the Python library. """
 
-    @ddt.data(
-        *FULL_TEST_DATA
-    )
+    @ddt.data(*FULL_TEST_DATA)
     @ddt.unpack
-    def test_run(self,      # type: TestStuff
-                 fname,     # type: str
-                 idx,       # type: int
-                 setenv,    # type: Dict[str, str]
-                 test,      # type: tdata.TestDef
-                 ):         # type: (...) -> None
+    def test_run(
+        self,  # type: TestStuff
+        fname,  # type: str
+        setenv,  # type: Dict[str, str]
+        test,  # type: tdefs.TestDef
+    ):  # type: (...) -> None
         """ Instantiate a confget object, load the data, check it. """
-        print('')
 
         save_env = dict(os.environ)
         try:
-            print('fname {fname} {idx:2} setenv {count} keys {kkk}'
-                  .format(fname=fname, idx=idx, count=len(setenv.keys()),
-                          kkk=test.keys))
             if set(test.args.keys()) & SKIP_ARGS:
-                print('- skipping: {skip}'.format(
-                    skip=' '.join(sorted(set(test.args.keys()) & SKIP_ARGS))))
                 return
 
             backend = test.get_backend()
-            print('- backend {back}'.format(back=backend))
             config = test.get_config()
-            print('- config {cfg}'.format(cfg=config))
             if test.setenv:
                 os.environ.update(setenv)
 
             if test.stdin:
-                fname = os.environ['TESTDIR'] + '/' + test.stdin
-                print('- reopening {fname} as stdin'.format(fname=fname))
-                with open(fname, mode='r') as stdin:
+                fname = os.environ["TESTDIR"] + "/" + test.stdin
+                with open(fname, mode="r") as stdin:
                     save_stdin = sys.stdin
                     try:
                         sys.stdin = stdin
                         obj = backend(config)
-                        print('- obj {obj}'.format(obj=obj))
                         data = obj.read_file()
                     finally:
                         sys.stdin = save_stdin
             else:
                 obj = backend(config)
-                print('- obj {obj}'.format(obj=obj))
                 data = obj.read_file()
 
-            print('- sections: {sect}'.format(sect=sorted(data.keys())))
             res = cformat.filter_vars(config, data)
-            print('- result: {res}'.format(res=res))
             output = test.do_xform(res)
-            print('- transformed: {output}'.format(output=repr(output)))
             test.output.check_result(output)
         finally:
             if test.setenv:
